==> react-layout-breakpoint-split-1.5.0.tgz: package/lib/index.js <==
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import ViewportResize from './viewport-resize';

var LayoutBreakpointSplit =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(LayoutBreakpointSplit, _Component);

  function LayoutBreakpointSplit(props) {
    var _this;

    _this = _Component.call(this, props) || this;
    _this.state = {};
    _this.onViewportResize = _this.onViewportResize.bind(_assertThisInitialized(_this));
    return _this;
  }

  var _proto = LayoutBreakpointSplit.prototype;

  _proto.componentDidMount = function componentDidMount() {
    ViewportResize.addListener(this.onViewportResize);
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    ViewportResize.removeListener(this.onViewportResize);
  };

  _proto.shouldComponentUpdate = function shouldComponentUpdate(nextProps, nextState) {
    return nextState.isSplitted !== this.state.isSplitted || nextProps.current !== this.props.current || nextProps.children !== this.props.children;
  };

  _proto.onViewportResize = function onViewportResize(width, height) {
    var breakpoint = this.props.breakpoint;
    this.setState({
      isSplitted: width <= breakpoint
    });
  };

  _proto.render = function render() {
    var _this$props = this.props,
        children = _this$props.children,
        current = _this$props.current;
    var isSplitted = this.state.isSplitted;
    children = isSplitted ? [children[current]] : children;
    var content = React.Children.map(children, function (_ref, index) {
      var Type = _ref.type,
          props = _ref.props;
      return React.createElement(Type, Object.assign({}, props, {
        key: index,
        className: cx(props.className, isSplitted && 'sui-LayoutBreakpointSplit-currentView')
      }));
    });
    var className = cx('sui-LayoutBreakpointSplit', this.props.className);
    return React.createElement("span", {
      className: className
    }, content);
  };

  return LayoutBreakpointSplit;
}(Component);

LayoutBreakpointSplit.displayName = 'LayoutBreakpointSplit';
LayoutBreakpointSplit.defaultProps = {
  current: 0
};
export default LayoutBreakpointSplit;

==> react-layout-breakpoint-split-1.6.0.tgz: package/lib/index.js <==
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import ViewportResize from './viewport-resize';

var LayoutBreakpointSplit = /*#__PURE__*/function (_Component) {
  _inheritsLoose(LayoutBreakpointSplit, _Component);

  function LayoutBreakpointSplit(props) {
    var _this;

    _this = _Component.call(this, props) || this;
    _this.state = {};
    _this.onViewportResize = _this.onViewportResize.bind(_assertThisInitialized(_this));
    return _this;
  }

  var _proto = LayoutBreakpointSplit.prototype;

  _proto.componentDidMount = function componentDidMount() {
    ViewportResize.addListener(this.onViewportResize);
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    ViewportResize.removeListener(this.onViewportResize);
  };

  _proto.shouldComponentUpdate = function shouldComponentUpdate(nextProps, nextState) {
    return nextState.isSplitted !== this.state.isSplitted || nextProps.current !== this.props.current || nextProps.children !== this.props.children;
  };

  _proto.onViewportResize = function onViewportResize(width, height) {
    var breakpoint = this.props.breakpoint;
    this.setState({
      isSplitted: width <= breakpoint
    });
  };

  _proto.render = function render() {
    var _this$props = this.props,
        children = _this$props.children,
        current = _this$props.current;
    var isSplitted = this.state.isSplitted;
    children = isSplitted ? [children[current]] : children;
    var content = React.Children.map(children, function (_ref, index) {
      var Type = _ref.type,
          props = _ref.props;
      return React.createElement(Type, Object.assign({}, props, {
        key: index,
        className: cx(props.className, isSplitted && 'sui-LayoutBreakpointSplit-currentView')
      }));
    });
    var className = cx('sui-LayoutBreakpointSplit', this.props.className);
    return React.createElement("span", {
      className: className
    }, content);
  };

  return LayoutBreakpointSplit;
}(Component);

LayoutBreakpointSplit.displayName = 'LayoutBreakpointSplit';
LayoutBreakpointSplit.defaultProps = {
  current: 0
};
export default LayoutBreakpointSplit;
